module SSG.HTML.ElementTypes

||| Proof that the element type identified by the given string is a void element
public export
data IsVoid : String -> Type where
  IsArea : IsVoid "area"
  IsBase : IsVoid "base"
  IsBr : IsVoid "br"
  IsCol : IsVoid "col"
  IsImg : IsVoid "img"
  IsInput : IsVoid "input"
  IsLink : IsVoid "link"
  IsMeta : IsVoid "meta"
  IsParam : IsVoid "param"
  IsSource : IsVoid "source"
  IsTrack : IsVoid "track"
  IsWbr : IsVoid "wbr"

||| Proof that the element type identified by the given string is a raw text
||| element
public export
data IsRawText : String -> Type where
  IsScript : IsRawText "script"
  IsStyle : IsRawText "style"
||| Proof that the element type identified by the given string is an escapable
||| raw text element
public export
data IsEscapableRawText : String -> Type where
  IsTextarea : IsEscapableRawText "textarea"
  IsTitle : IsEscapableRawText "title"

||| Proof that the element type idenitified by the given string is a normal
||| element
public export
data IsNormal : String -> Type where
  -- Document element
  IsHtml : IsNormal "html"
  -- Sections
  IsHead : IsNormal "head"
  IsBody : IsNormal "body"
  IsArticle : IsNormal "article"
  IsSection : IsNormal "section"
  IsNav : IsNormal "nav"
  IsAside : IsNormal "aside"
  IsH1 : IsNormal "h1"
  IsH2 : IsNormal "h2"
  IsH3 : IsNormal "h3"
  IsH4 : IsNormal "h4"
  IsH5 : IsNormal "h5"
  IsH6 : IsNormal "h6"
  IsHgroup : IsNormal "hgroup"
  IsHeader : IsNormal "header"
  IsFooter : IsNormal "footer"
  IsAddress : IsNormal "address"
  -- Grouping content
  IsP : IsNormal "p"
  IsHr : IsNormal "hr"
  IsPre : IsNormal "pre"
  IsBlockquote : IsNormal "blockquote"
  IsOl : IsNormal "ol"
  IsUl : IsNormal "ul"
  IsMenu : IsNormal "menu"
  IsLi : IsNormal "li"
  IsDl : IsNormal "dl"
  IsDt : IsNormal "dt"
  IsDd : IsNormal "dd"
  IsFigure : IsNormal "figure"
  IsFigcaption : IsNormal "figcaption"
  IsMain : IsNormal "main"
  IsSearch : IsNormal "search"
  IsDiv : IsNormal "div"
  -- Text level semantics
  IsA : IsNormal "a"
  IsEm : IsNormal "em"
  IsStrong : IsNormal "strong"
  IsSmall : IsNormal "small"
  IsS : IsNormal "s"
  IsCite : IsNormal "cite"
  IsQ : IsNormal "q"
  IsDfn : IsNormal "dfn"
  IsAbbr : IsNormal "abbr"
  IsRuby : IsNormal "ruby"
  IsRt : IsNormal "rt"
  IsRp : IsNormal "rp"
  IsData : IsNormal "data"
  IsTime : IsNormal "time"
  IsCode : IsNormal "code"
  IsVar : IsNormal "var"
  IsSamp : IsNormal "samp"
  IsKbd : IsNormal "kbd"
  IsSub : IsNormal "sub"
  IsSup : IsNormal "sup"
  IsI : IsNormal "i"
  IsB : IsNormal "b"
  IsU : IsNormal "u"
  IsMark : IsNormal "mark"
  IsBdi : IsNormal "bdi"
  IsBdo : IsNormal "bdo"
  IsSpan : IsNormal "span"
